@@ -1,6 +1,8 @@
 # coding:utf-8
 import time
 import re
+import os
+from ks3.utils import get_default_user_agent
 
 try:
     import http.client as httpcli  # for Python 3
@@ -61,7 +63,7 @@ def get_object_url(age, bucket="", key="", secret_access_key="", access_key_id="
 
 def make_request(server, port, access_key_id, access_key_secret, method, 
                  bucket="", key="", query_args=None, headers=None, data="", 
-                 metadata=None, call_fmt=CallingFormat.SUBDOMAIN, is_secure=False,domain_mode=False,need_auth_header=True, timeout = 10):
+                 metadata=None, call_fmt=CallingFormat.SUBDOMAIN, is_secure=False,domain_mode=False,need_auth_header=True, timeout = 10, ua_addon=''):
     if not headers:
         headers = {}
     #if not query_args:
@@ -95,6 +97,7 @@ def make_request(server, port, access_key_id, access_key_secret, method,
         connection = httpcli.HTTPConnection(host)
 
     connection.timeout = timeout
+    headers['User-Agent'] = get_default_user_agent() + ' ' + ua_addon
     final_headers = merge_meta(headers, metadata)
     if method == "PUT" and "Content-Length" not in final_headers and not data:
         final_headers["Content-Length"] = "0"
@@ -122,8 +125,10 @@ def make_request(server, port, access_key_id, access_key_secret, method,
                     except Exception as err:
                         print(str(err))
                 else:
+                    if hasattr(data, 'read'):
+                        data.seek(0, os.SEEK_SET)
                     return make_request(new_server, port, access_key_id, access_key_secret, method, bucket, key, query_args,
-                                    headers, data, metadata, call_fmt, is_secure,need_auth_header=False)
+                                    headers, data, metadata, call_fmt, is_secure, need_auth_header=True, ua_addon=ua_addon)
     return resp
 
 # 发送awsv4的请求
