@@ -191,7 +191,7 @@ class Key(object):
     def generate_url(self, expires_in, method='GET', headers=None,
                      query_auth=True, force_http=False, response_headers=None,
                      expires_in_absolute=False, version_id=None,
-                     policy=None, reduced_redundancy=False, encrypt_key=False,domain=False):
+                     policy=None, reduced_redundancy=False, encrypt_key=False, domain=False, image_attrs=None):
         """
         Generate a URL to access this key.
         """
@@ -213,8 +213,12 @@ class Key(object):
         #    headers[provider.server_side_encryption_header] = 'AES256'
         #headers = merge_meta(headers, self.metadata, provider)
 
+        name = self.name
+        if image_attrs is not None:
+            name = name + image_attrs
+
         url = self.bucket.connection.generate_url(expires_in, method,
-                                                   self.bucket.name, self.name,
+                                                   self.bucket.name, name,
                                                    headers, query_auth,
                                                    force_http,
                                                    response_headers,
